@@ -8,11 +8,11 @@ data_name = "lens_light_dev_vaucouleurs"
 instrument = "vro"
 
 
-def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
+def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(lens=al.GalaxyModel(redshift=0.5, sersic=al.lp.EllipticalSersic)),
         bin_up_factor=2,
         search=search,
@@ -20,7 +20,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase1.search.const_efficiency_mode = True
     phase1.search.n_live_points = 40
-    phase1.search.sampling_efficiency = 0.8
+    phase1.search.facc = 0.8
 
     return al.PipelineDataset(name, phase1)
 
